@@ -4,13 +4,14 @@ from bluer_sbc.README.designs import (
     bryce,
     cheshmak,
     nafha,
+    pwm_generator,
     regulated_bus,
     shelter,
-    swallow,
-    swallow_head,
     template,
     ultrasonic_sensor_tester,
 )
+from bluer_sbc.README.designs.swallow import docs as swallow
+from bluer_sbc.README.designs.swallow_head import docs as swallow_head
 
 
 docs = (
@@ -19,6 +20,7 @@ docs = (
     + bryce.docs
     + cheshmak.docs
     + nafha.docs
+    + pwm_generator.docs
     + regulated_bus.docs
     + shelter.docs
     + swallow_head.docs
