@@ -29,13 +29,14 @@ items = ImageItems(
             "20251103_215257.jpg",
             "20251103_215301.jpg",
             "20251103_215319.jpg",
+            "20251116_224456.jpg",
         ]
     },
 )
 
 parts = {
     "dsn-vc288": "",
-    "charging-port": "",
+    "dc-power-plug": "",
     "pwm-manual-dc-motor-controller": "",
     "heater-element": "12 V, 4.5 Ω, 32 w",
 }
