@@ -81,7 +81,7 @@ db_of_parts["rpi"] = Part(
 
 db_of_parts["SLA-Battery"] = Part(
     info=[
-        "Rechargeable sealed lead acid battery, 12 V, 7 Ah",
+        "Rechargeable sealed lead acid battery",
     ],
     images=[
         "battery.png",
@@ -328,21 +328,22 @@ db_of_parts["1N4148"] = Part(
     ],
 )
 
-db_of_parts["40-inch-TV"] = Part(
+db_of_parts["TV"] = Part(
     info=[
-        "40 inch TV",
+        "TV",
     ],
     images=[
-        "40-inch-TV.jpg",
+        "tv.jpg",
     ],
 )
 
-db_of_parts["power-station"] = Part(
+db_of_parts["power-inverter"] = Part(
     info=[
-        "power station.",
+        "power inverter, 12 VDC -> 220 VAC.",
+        "pure sine wave.",
     ],
     images=[
-        "power-station.jpeg",
+        "power-inverter.jpg",
     ],
 )
 
@@ -355,18 +356,18 @@ db_of_parts["TV-bracket"] = Part(
     ],
 )
 
-db_of_parts["on-off-switch"] = Part(
+db_of_parts["dc-switch"] = Part(
     info=[
-        "on/off switch, 12V DC 10 A, with indicator led",
+        "on/off DC switch with indicator led",
     ],
     images=[
         "on-off-switch.png",
     ],
 )
 
-db_of_parts["charging-port"] = Part(
+db_of_parts["dc-power-plug"] = Part(
     info=[
-        "charging port 5.5 mm",
+        "DC power plug, 5.5 mm",
     ],
     images=[
         "charging-port.jpg",
@@ -386,6 +387,15 @@ db_of_parts["dsn-vc288"] = Part(
     ],
 )
 
+db_of_parts["dc-volt-meter"] = Part(
+    info=[
+        "DC volt meter",
+    ],
+    images=[
+        "dsn-vc288.jpg",
+    ],
+)
+
 db_of_parts["nuts-bolts-spacers"] = Part(
     info=[
         "nuts, bolts, and spacers",
@@ -413,6 +423,15 @@ db_of_parts["white-terminal"] = Part(
     ],
 )
 
+db_of_parts["green-terminal"] = Part(
+    info=[
+        "green terminal",
+    ],
+    images=[
+        "green-terminal.jpg",
+    ],
+)
+
 db_of_parts["dupont-cables"] = Part(
     info=[
         "dupont cables, female to female",
@@ -501,7 +520,7 @@ db_of_parts["tb6612"] = Part(
     ],
 )
 
-db_of_parts["small-on-off-switch"] = Part(
+db_of_parts["small-dc-switch"] = Part(
     info=[
         "small on/off switch",
     ],
@@ -537,9 +556,9 @@ db_of_parts["micro-usb-cable"] = Part(
     ],
 )
 
-db_of_parts["charger-socket"] = Part(
+db_of_parts["dc-power-jack"] = Part(
     info=[
-        "charger socket 5.5 mm",
+        "DC power jack, 5.5 mm",
     ],
     images=[
         "charger-socket.jpg",
@@ -609,6 +628,70 @@ db_of_parts["sd-card-32-gb"] = Part(
     ],
 )
 
+db_of_parts["dc-fuse"] = Part(
+    info=[
+        "DC fuse, ANL or MIDI type",
+    ],
+    images=[
+        "dc-fuse.jpg",
+    ],
+)
+
+db_of_parts["mcb"] = Part(
+    info=[
+        "miniature circuit breaker (MCB)",
+    ],
+    images=[
+        "mcb-3.jpg",
+    ],
+)
+
+db_of_parts["ac-switch"] = Part(
+    info=[
+        "AC switch",
+    ],
+    images=[
+        "ac-switch.jpg",
+    ],
+)
+
+db_of_parts["safety-fuse"] = Part(
+    info=[
+        "safety fuse",
+        "residual current device (RCD / GFCI)",
+    ],
+    images=[
+        "safety-fuse.jpg",
+    ],
+)
+
+db_of_parts["ac-volt-meter"] = Part(
+    info=[
+        "AC volt meter",
+    ],
+    images=[
+        "ac-volt-meter.jpg",
+    ],
+)
+
+db_of_parts["emergency-stop"] = Part(
+    info=[
+        "emergency stop switch",
+    ],
+    images=[
+        "emergency-stop.jpg",
+    ],
+)
+
+db_of_parts["power-adapter"] = Part(
+    info=[
+        "AC to DC power adapter",
+    ],
+    images=[
+        "power-adapter.jpg",
+    ],
+)
+
 db_of_parts["template"] = Part(
     info=[
         "template",
